@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2022 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ from hashlib import md5
 
 from Nagstamon.Config import (conf,
                               OS,
-                              OS_DARWIN)
+                              OS_MACOS)
 
 # states needed for gravity comparison for notification and Generic.py
 STATES = ['UP',
@@ -103,7 +103,7 @@ class FilesDict(dict):
         :param key:
         :return:
         """
-        if OS == OS_DARWIN:
+        if OS == OS_MACOS:
             if not os.path.exists(key):
                 # pyinstaller temp folder seems to be emptied completely after a while
                 # so the directories containing the resources have to be recreated too
@@ -455,6 +455,13 @@ def get_distro():
                 if not line.startswith('#'):
                     key, value = line.split('=', 1)
                     os_release_dict[key] = value.strip('"').strip("'")
+            # Since CentOS Linux got retired by Red Hat, there are various RHEL derivatives/clones; flow is:
+            # CentOS Stream -> Red Hat Enterprise Linux -> (AlmaLinux, EuroLinux, Oracle Linux, Rocky Linux)
+            # Goal of this hack is to rule them all as Red Hat Enterprise Linux, the baseline distribution.
+            if re.search('^platform:el\d+$', os_release_dict.get('PLATFORM_ID', 'unknown')):
+                os_release_dict['ID'] = 'rhel'
+                os_release_dict['VERSION_ID'] = os_release_dict.get('VERSION_ID', 'unknown').split('.', 1)[0]
+                os_release_dict['NAME'] = 'Red Hat Enterprise Linux'
             return (os_release_dict.get('ID').lower(),
                     os_release_dict.get('VERSION_ID', 'unknown').lower(),
                     os_release_dict.get('NAME').lower())
@@ -465,7 +472,6 @@ def get_distro():
         dist_name, dist_version, dist_id = platform.dist()
         return dist_name.lower(), dist_version, dist_id
 
-
 # depending on column different functions have to be used
 # 0 + 1 are column "Hosts", 1 + 2 are column "Service" due to extra font flag pictograms
 SORT_COLUMNS_FUNCTIONS = {0: compare_host,
