@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2022 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -167,7 +167,7 @@ class CentreonServer(GenericServer):
             # ID of the user is needed by some requests
             user_id = data["contact"]["id"]
 
-            if conf.debug_mode == True:
+            if conf.debug_mode:
                 self.Debug(server='[' + self.get_name() + ']',
                            debug='API login : ' + self.username + ' / ' + self.password + ' > Token : ' + token + ' > User ID : ' + str(
                                user_id))
@@ -200,7 +200,7 @@ class CentreonServer(GenericServer):
 
             fqdn = str(data["result"][0]["fqdn"])
 
-            if conf.debug_mode == True:
+            if conf.debug_mode:
                 self.Debug(server='[' + self.get_name() + ']',
                            debug='Get Host FQDN or address : ' + host + " / " + fqdn)
 
@@ -235,7 +235,7 @@ class CentreonServer(GenericServer):
 
                 host_id = data["result"][0]["id"]
 
-                if conf.debug_mode == True:
+                if conf.debug_mode:
                     self.Debug(server='[' + self.get_name() + ']', debug='Get Host ID : ' + host + " / " + str(host_id))
                 return host_id
 
@@ -273,7 +273,7 @@ class CentreonServer(GenericServer):
                     host_id = data["result"][0]["parent"]["id"]
                 service_id = data["result"][0]["id"]
 
-                if conf.debug_mode == True:
+                if conf.debug_mode:
                     self.Debug(server='[' + self.get_name() + ']',
                                debug='Get Host / Service ID : ' + str(host_id) + " / " + str(service_id))
                 return host_id, service_id
@@ -719,11 +719,11 @@ class CentreonServer(GenericServer):
             return Result(result=result, error=error)
 
     def check_session(self):
-        if conf.debug_mode == True:
+        if conf.debug_mode:
             self.Debug(server='[' + self.get_name() + ']', debug='Checking session status')
 
         try:
-            if conf.debug_mode == True:
+            if conf.debug_mode:
                 self.Debug(server='[' + self.get_name() + ']',
                            debug='Check-session, the token expire if not been used for more than one hour. Current Token = ' + str(
                                self.token))
@@ -734,10 +734,15 @@ class CentreonServer(GenericServer):
             result = self.FetchURL(self.urls_centreon['resources'] + '?' + urllib.parse.urlencode(cgi_data),
                                    giveback="raw")
 
-           # If we got an 403 or 401, the token expired and must be renewed
-            if result.status_code == 403 or result.status_code == 401:
+           # If we got an 403 or 401 (and 500 for version 21.), the token expired and must be renewed
+            if self.centreon_version_major == 21:
+                ressources_response_list = [401, 403, 500]
+            else:
+                ressources_response_list = [401, 403]
+
+            if result.status_code in ressources_response_list:
                 self.token = self.get_token().result
-                if conf.debug_mode == True:
+                if conf.debug_mode:
                     self.Debug(server='[' + self.get_name() + ']', debug='Check-session, session renewed')
                 result = self.FetchURL(self.urls_centreon['resources'] + '?' + urllib.parse.urlencode(cgi_data),
                                        giveback="raw")
