@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2022 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@ import socket
 import sys
 import traceback
 import urllib.parse
+from urllib.request import getproxies
 
 from bs4 import BeautifulSoup
 import requests
@@ -56,10 +57,10 @@ from Nagstamon.Config import (AppInfo,
                               conf,
                               debug_queue,
                               OS,
-                              OS_DARWIN,
+                              OS_MACOS,
                               RESOURCES)
 
-if OS == OS_DARWIN:
+if OS == OS_MACOS:
     # requests_gssapi is newer but not available everywhere
     try:
         # extra imports needed to get it compiled on macOS
@@ -69,9 +70,13 @@ if OS == OS_DARWIN:
     except ImportError:
         from requests_kerberos import HTTPKerberosAuth as HTTPSKerberos
 else:
-    # requests_gssapi needs installation of KfW - Kerberos for Windows
-    # requests_kerberoes doesn't
-    from requests_kerberos import HTTPKerberosAuth as HTTPSKerberos
+    # requests_gssapi is newer but not available everywhere
+    try:
+        # requests_gssapi needs installation of KfW - Kerberos for Windows
+        # requests_kerberoes doesn't
+        from requests_kerberos import HTTPKerberosAuth as HTTPSKerberos
+    except ImportError:
+        from requests_gssapi import HTTPSPNEGOAuth as HTTPSKerberos
 
 # disable annoying SubjectAltNameWarning warnings
 try:
@@ -216,7 +221,7 @@ class GenericServer(object):
 
         # macOS pyinstaller onefile conglomerate tends to lose cacert.pem due to macOS temp folder cleaning
         self.cacert_path = self.cacert_content = False
-        if OS == OS_DARWIN:
+        if OS == OS_MACOS:
             # trying to find root path when run by pyinstaller onefile, must be something like
             # /var/folders/7w/hfvrg7v92x3gjt95cqh974240000gn/T/_MEIQ3l3u3
             root_path = Path(RESOURCES).parent.parent
@@ -241,6 +246,12 @@ class GenericServer(object):
         self.host_filter = 'state !=0'
         self.service_filter = 'state !=0 or host.state != 0'
 
+        # Opsview hashtag filter
+        self.hashtag_filter = ''
+
+        # Opsview can_change_only option
+        self.can_change_only = False
+
         # Sensu/Uchiwa/??? Datacenter/Site config
         self.monitor_site = 'Site 1'
 
@@ -328,9 +339,13 @@ class GenericServer(object):
         # check if proxies have to be used
         if self.use_proxy is True:
             if self.use_proxy_from_os is True:
-                # if .trust_enf is true the system environment will be evaluated
-                requester.trust_env = True
-                requester.proxies = dict()
+                # get proxies from system directly instead of via trust_env
+                requester.proxies = getproxies()
+                # check for missing '/' to make proxies work
+                for scheme, proxy_url in requester.proxies.items():
+                    if not proxy_url.endswith('/'):
+                        requester.proxies[scheme] = proxy_url + '/'
+                pass
             else:
                 # check if username and password are given and provide credentials if needed
                 if self.proxy_username == self.proxy_password == '':
@@ -350,8 +365,6 @@ class GenericServer(object):
                     # fill session.proxies for both protocols
                     requester.proxies = {'http': proxy_url, 'https': proxy_url}
         else:
-            # disable evaluation of environment variables
-            requester.trust_env = False
             requester.proxies = None
 
     def reset_HTTP(self):
@@ -1441,7 +1454,7 @@ class GenericServer(object):
                         cgi_data_log = cgi_data
                     self.Debug(server=self.get_name(), debug='FetchURL: ' + url + ' CGI Data: ' + str(cgi_data_log))
 
-                if OS == OS_DARWIN and self.cacert_path and not self.cacert_path.is_file():
+                if OS == OS_MACOS and self.cacert_path and not self.cacert_path.is_file():
                     # pyinstaller temp folder seems to be emptied completely after a while
                     # so the directories containing the resources have to be recreated too
                     self.cacert_path.parent.mkdir(exist_ok=True)
