@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2022 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -104,7 +104,7 @@ class IcingaDBWebServer(GenericServer):
                     form = login.result.find('form')
                     form_inputs = {}
                     for form_input in ('redirect', 'formUID', 'CSRFToken', 'btn_submit'):
-                        if not form.find('input', {'name': form_input}) is None:
+                        if form is not None and not form.find('input', {'name': form_input}) is None:
                             form_inputs[form_input] = form.find('input', {'name': form_input})['value']
                         else:
                             form_inputs[form_input] = ''
@@ -191,7 +191,7 @@ class IcingaDBWebServer(GenericServer):
                     h = dict(host.items())
 
                     # host
-                    if self.use_display_name_host == False:
+                    if not self.use_display_name_host:
                         # according to http://sourceforge.net/p/nagstamon/bugs/83/ it might
                         # better be name instead of display_name
                         host_name = h['name']
@@ -272,7 +272,7 @@ class IcingaDBWebServer(GenericServer):
                     # make dict of tuples for better reading
                     s = dict(service.items())
 
-                    if self.use_display_name_host == False:
+                    if not self.use_display_name_host:
                         # according to http://sourceforge.net/p/nagstamon/bugs/83/ it might
                         # better be name instead of display_name
                         host_name = s['host']['name']
